WeIcons class

Constructors

WeIcons()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

clear → const IconData
close → const IconData
del → const IconData
down → const IconData
hook → const IconData
info → const IconData
loading → const IconData
success → const IconData
time → const IconData
triangle → const IconData