WeInput class

Inheritance

Constructors

WeInput({Key? key, dynamic label, double height = 48, String defaultValue = '', int maxLines = 1, int? maxLength, String? hintText, FocusNode? focusNode, Widget? footer, bool showClear = false, TextAlign textAlign = TextAlign.start, TextInputType textInputType = TextInputType.text, bool obscureText = false, TextStyle? style, bool autofocus = false, double labelWidth = 80.0, TextInputAction? textInputAction, dynamic onChange(String value)?, VoidCallback? onEditingComplete, ValueChanged<String>? onSubmitted})

Properties

autofocus bool
final
defaultValue String
final
focusNode FocusNode?
final
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
hintText String?
final
key Key?
Controls how one widget replaces another widget in the tree.
final
label → dynamic
final
labelWidth double
final
maxLength int?
final
maxLines int
final
obscureText bool
final
onChange → dynamic Function(String value)?
final
onEditingComplete VoidCallback?
final
onSubmitted ValueChanged<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showClear bool
final
style TextStyle?
final
textAlign TextAlign
final
textInputAction TextInputAction?
final
textInputType TextInputType
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() WeInputState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited