WeConfig class

Constructors

WeConfig({WeToastInfoAlign toastInfoAlign = WeToastInfoAlign.center, int toastInfoDuration = 2500, int toastLoadingDuration = 5000, int toastSuccessDuration = 2500, int toastFailDuration = 2500, int notifyDuration = 3000, int notifySuccessDuration = 3000, int notifyErrorDuration = 3000})

Properties

hashCode int
The hash code for this object.
no setterinherited
notifyDuration int
final
notifyErrorDuration int
final
notifySuccessDuration int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toastFailDuration int
final
toastInfoAlign WeToastInfoAlign
final
toastInfoDuration int
final
toastLoadingDuration int
final
toastSuccessDuration int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited