WeTheme class

Constructors

WeTheme({Color primaryColor = _primaryColor, Color primaryColorDisabled = _primaryColorDisabled, Color warnColor = _warnColor, Color warnColorDisabled = _warnColorDisabled, Color defaultBackgroundColor = _defaultBackgroundColor, Color defaultBorderColor = _defaultBorderColor, Color maskColor = _maskColor})

Properties

defaultBackgroundColor Color
final
defaultBorderColor Color
final
hashCode int
The hash code for this object.
no setterinherited
maskColor Color
final
primaryColor Color
final
primaryColorDisabled Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnColor Color
final
warnColorDisabled Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited